/*******************************************************************************

  Intel Data Center Bridging (DCB) Software
  Copyright(c) 2007-2008 Intel Corporation.

  This program is free software; you can redistribute it and/or modify it
  under the terms and conditions of the GNU General Public License,
  version 2, as published by the Free Software Foundation.

  This program is distributed in the hope it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.

  The full GNU General Public License is included in this distribution in
  the file called "COPYING".

  Contact Information:
  e1000-eedc Mailing List <e1000-eedc@lists.sourceforge.net>
  Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497

*******************************************************************************/

#ifndef _GNUTIL_H
#define _GNUTIL_H

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <asm/types.h>
#include <asm/errno.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <linux/types.h>
#include <linux/netlink.h>

/* DCB configuration commands  */
enum {
        DCB_C_UNDEFINED,
        DCB_C_GSTATE,
        DCB_C_SSTATE,
        DCB_C_PG_STATS,
        DCB_C_PGTX_GCFG,
        DCB_C_PGTX_SCFG,
        DCB_C_PGRX_GCFG,
        DCB_C_PGRX_SCFG,
        DCB_C_PFC_GCFG,
        DCB_C_PFC_SCFG,
        DCB_C_PFC_STATS,
	DCB_C_GLINK_SPD,
	DCB_C_SLINK_SPD,
	DCB_C_SET_ALL,
	DCB_C_GPERM_HWADDR,
        __DCB_C_ENUM_MAX,
};

#define IXGBE_DCB_C_MAX (__DCB_C_ENUM_MAX - 1)

/* DCB configuration attributes */
enum {
	DCB_A_UNDEFINED = 0,
	DCB_A_IFNAME,
	DCB_A_STATE,
	DCB_A_PFC_STATS,
	DCB_A_PFC_CFG,
	DCB_A_PG_STATS,
	DCB_A_PG_CFG,
	DCB_A_LINK_SPD,
	DCB_A_SET_ALL,
	DCB_A_PERM_HWADDR,
	__DCB_A_ENUM_MAX,
};

#define IXGBE_DCB_A_MAX (__DCB_A_ENUM_MAX - 1)

/* PERM HWADDR attributes */
enum {
        PERM_HW_A_UNDEFINED,
        PERM_HW_A_0,
        PERM_HW_A_1,
        PERM_HW_A_2,
        PERM_HW_A_3,
        PERM_HW_A_4,
        PERM_HW_A_5,
        PERM_HW_A_ALL,
        __PERM_HW_A_ENUM_MAX,
};

#define IXGBE_DCB_PERM_HW_A_MAX        (__PERM_HW_A_ENUM_MAX - 1)

/* PFC configuration attributes */
enum {
	PFC_A_UP_UNDEFINED,
	PFC_A_UP_0,
	PFC_A_UP_1,
	PFC_A_UP_2,
	PFC_A_UP_3,
	PFC_A_UP_4,
	PFC_A_UP_5,
	PFC_A_UP_6,
	PFC_A_UP_7,
	PFC_A_UP_MAX, /* Used as an iterator cap */
	PFC_A_UP_ALL,
	__PFC_A_UP_ENUM_MAX,
};

#define IXGBE_DCB_PFC_A_UP_MAX (__PFC_A_UP_ENUM_MAX - 1)

/* Priority Group Traffic Class and Bandwidth Group
 * configuration attributes */
enum {
        PG_A_UNDEFINED,
        PG_A_TC_0,
        PG_A_TC_1,
        PG_A_TC_2,
        PG_A_TC_3,
        PG_A_TC_4,
        PG_A_TC_5,
        PG_A_TC_6,
        PG_A_TC_7,
        PG_A_TC_MAX, /* Used as an iterator cap */
        PG_A_TC_ALL,
        PG_A_BWG_0,
        PG_A_BWG_1,
        PG_A_BWG_2,
        PG_A_BWG_3,
        PG_A_BWG_4,
        PG_A_BWG_5,
        PG_A_BWG_6,
        PG_A_BWG_7,
        PG_A_BWG_MAX, /* Used as an iterator cap */
        PG_A_BWG_ALL,
        __PG_A_ENUM_MAX,
};

#define IXGBE_DCB_PG_A_MAX     (__PG_A_ENUM_MAX - 1)


enum {
	TC_A_PARAM_UNDEFINED,
	TC_A_PARAM_STRICT_PRIO,
	TC_A_PARAM_BW_GROUP_ID,
	TC_A_PARAM_BW_PCT_IN_GROUP,
	TC_A_PARAM_UP_MAPPING,
	TC_A_PARAM_MAX, /* Used as an iterator cap */
	TC_A_PARAM_ALL,
	__TC_A_PARAM_ENUM_MAX,
};

#define IXGBE_DCB_TC_A_PARAM_MAX (__TC_A_PARAM_ENUM_MAX - 1)

enum dcb_pfc_type {
	pfc_disabled = 0,
	pfc_enabled_tx,
	pfc_enabled_rx,
	pfc_enabled_full
};

enum strict_prio_type {
	prio_none = 0,
	prio_group,
	prio_link
};

struct tc_config {
	__u8 prio_type;
	__u8 bwg_id;
	__u8 bwg_percent;
	__u8 up_to_tc_bitmap;
};

/* Data structures (and macros) needed that are not including in any library. */

struct genlmsghdr
{
	__u8  cmd;
	__u8  version;
	__u16 reserved;
};

/*
struct nlattr
{
	__u16 nla_len;
	__u16 nla_type;
};
*/

enum {
	CTRL_CMD_UNSPEC,
	CTRL_CMD_NEWFAMILY,
	CTRL_CMD_DELFAMILY,
	CTRL_CMD_GETFAMILY,
	CTRL_CMD_NEWOPS,
	CTRL_CMD_DELOPS,
	CTRL_CMD_GETOPS,
	__CTRL_CMD_MAX,
};

#define CTRL_CMD_MAX (__CTRL_CMD_MAX - 1)

enum {
	CTRL_ATTR_UNSPEC,
	CTRL_ATTR_FAMILY_ID,
	CTRL_ATTR_FAMILY_NAME,
	CTRL_ATTR_VERSION,
	CTRL_ATTR_HDRSIZE,
	CTRL_ATTR_MAXATTR,
	CTRL_ATTR_OPS,
	__CTRL_ATTR_MAX,
};

#define CTRL_ATTR_MAX (__CTRL_ATTR_MAX - 1)

#define GENL_ID_CTRL         0x10
#define GENL_HDRLEN          NLMSG_ALIGN(sizeof(struct genlmsghdr))
#define GENLMSG_DATA(nlh)    ((void *)(((char *)NLMSG_DATA(nlh)) + GENL_HDRLEN))
#define GENLMSG_PAYLOAD(nlh) (NLMSG_PAYLOAD(nlh, 0) - GENL_HDRLEN)
#define NLA_ALIGNTO          4
#define NLA_ALIGN(len)       (((len) + NLA_ALIGNTO - 1) & ~(NLA_ALIGNTO - 1))
#define NLA_HDRLEN           ((int) NLA_ALIGN(sizeof(struct nlattr)))
#define NLA_DATA(nla)        ((void *)((char*)(nla) + NLA_HDRLEN))
#define NLA_PAYLOAD(len)     (len - NLA_HDRLEN)

#define IXGBE_NLTYPE_DCB_NAME         "IXGBE_DCB"

__u16 fid;
int nl_sd;
char family[] = IXGBE_NLTYPE_DCB_NAME;
int dbg = 1;
 
/* Maximum size of response requested or message sent */
#define MAX_MSG_SIZE    1024

#endif  /* _GNUTIL_H */
