#!/bin/bash
################################################################################
#
# Intel Data Center Bridging (DCB) Software
# Copyright(c) 2007-2008 Intel Corporation.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms and conditions of the GNU General Public License,
# version 2, as published by the Free Software Foundation.
#
# This program is distributed in the hope it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
#
# The full GNU General Public License is included in this distribution in
# the file called "COPYING".
#
# Contact Information:
# e1000-eedc Mailing List <e1000-eedc@lists.sourceforge.net>
# Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497
#
################################################################################

# test the app tlv for subtype 0

. ../test_fns.sh

REMOTE=$1
DEVICE=$2

TEST="app tlv tests"
echo Running: $TEST

RESULTS=t5.out
echo $TEST > $RESULTS

# phase 1
# change remote app params to !willing and change the app params
ssh $REMOTE dcbtool -r sc $DEVICE app:0 w:0 a:1 e:1 appcfg:db > junk
check_results sc_app.r1 "$TEST: remote set app !w, a, e, appcfg"

ssh $REMOTE dcbtool -r gc $DEVICE app:0 > junk
check_results gc_app.r1 "$TEST: remote get config app"

sleep 8

ssh $REMOTE dcbtool -r go $DEVICE app:0 > junk
check_results go_app.r1 "$TEST: remote get oper app"

ssh $REMOTE dcbtool -r gp $DEVICE app:0 > junk
check_results gp_app.r1 "$TEST: remote get peer app"


dcbtool -r gc $DEVICE app:fcoe > junk
check_results gc_app.l1 "$TEST: local get config app"

dcbtool -r go $DEVICE app:fcoe > junk
check_results go_app.l1 "$TEST: local get oper app"

dcbtool -r gp $DEVICE app:fcoe > junk
check_results gp_app.l1 "$TEST: local get peer app"

# phase 2
# change local app params to willing, advertise, enable
dcbtool -r sc $DEVICE app:0 w:1 a:1 e:1 > junk
check_results sc_app.l2 "$TEST: local set app w, a, e, !appcfg"

dcbtool -r gc $DEVICE app:fcoe > junk
check_results gc_app.l2 "$TEST: local get config app"

sleep 8

dcbtool -r go $DEVICE app:fcoe > junk
check_results go_app.l2 "$TEST: local get oper app"

dcbtool -r gp $DEVICE app:fcoe > junk
check_results gp_app.l2 "$TEST: local get peer app"


ssh $REMOTE dcbtool -r gc $DEVICE app:0 > junk
check_results gc_app.r2 "$TEST: remote get config app"

ssh $REMOTE dcbtool -r go $DEVICE app:0 > junk
check_results go_app.r2 "$TEST: remote get oper app"

ssh $REMOTE dcbtool -r gp $DEVICE app:0 > junk
check_results gp_app.r2 "$TEST: remote get peer app"


# phase 3 - set local appcfg - should still be opermode on
# change local app params to willing, advertise, enable
dcbtool -r sc $DEVICE app:0 appcfg:bb > junk
check_results sc_app.l3 "$TEST: local set app appcfg"

dcbtool -r gc $DEVICE app:fcoe > junk
check_results gc_app.l3 "$TEST: local get config app"

sleep 8

dcbtool -r go $DEVICE app:fcoe > junk
check_results go_app.l3 "$TEST: local get oper app"

dcbtool -r gp $DEVICE app:fcoe > junk
check_results gp_app.l3 "$TEST: local get peer app"


ssh $REMOTE dcbtool -r gc $DEVICE app:0 > junk
check_results gc_app.r3 "$TEST: remote get config app"

ssh $REMOTE dcbtool -r go $DEVICE app:0 > junk
check_results go_app.r3 "$TEST: remote get oper app"

ssh $REMOTE dcbtool -r gp $DEVICE app:0 > junk
check_results gp_app.r3 "$TEST: remote get peer app"


# phase 4 - set local !w - oper mode goes off
# change local app params to willing, advertise, enable
dcbtool -r sc $DEVICE app:0 w:0 > junk
check_results sc_app.l4 "$TEST: local set app !w"

dcbtool -r gc $DEVICE app:fcoe > junk
check_results gc_app.l4 "$TEST: local get config app"

sleep 8

dcbtool -r go $DEVICE app:fcoe > junk
check_results go_app.l4 "$TEST: local get oper app"

dcbtool -r gp $DEVICE app:fcoe > junk
check_results gp_app.l4 "$TEST: local get peer app"


ssh $REMOTE dcbtool -r gc $DEVICE app:0 > junk
check_results gc_app.r4 "$TEST: remote get config app"

ssh $REMOTE dcbtool -r go $DEVICE app:0 > junk
check_results go_app.r4 "$TEST: remote get oper app"

ssh $REMOTE dcbtool -r gp $DEVICE app:0 > junk
check_results gp_app.r4 "$TEST: remote get peer app"

# phase 5
# change remote app params to match local
ssh $REMOTE dcbtool -r sc $DEVICE app:fcoe appcfg:bb > junk
check_results sc_app.r5 "$TEST: remote set app appcfg to match peer"

ssh $REMOTE dcbtool -r gc $DEVICE app:0 > junk
check_results gc_app.r5 "$TEST: remote get config app"

sleep 8

ssh $REMOTE dcbtool -r go $DEVICE app:0 > junk
check_results go_app.r5 "$TEST: remote get oper app"

ssh $REMOTE dcbtool -r gp $DEVICE app:0 > junk
check_results gp_app.r5 "$TEST: remote get peer app"


dcbtool -r gc $DEVICE app:fcoe > junk
check_results gc_app.l5 "$TEST: local get config app"

dcbtool -r go $DEVICE app:fcoe > junk
check_results go_app.l5 "$TEST: local get oper app"

dcbtool -r gp $DEVICE app:fcoe > junk
check_results gp_app.l5 "$TEST: local get peer app"

cat $RESULTS
rm junk
